@@ -18,7 +18,7 @@
     License along with this library; if not, write to the Free
     Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: util.c,v 1.126 2001/09/24 16:29:02 mmclouglin Exp $
+    $Id: util.c,v 1.129 2003/04/28 12:07:37 michael Exp $
 
 ***************************************************************************/
 #include <assert.h>
@@ -28,7 +28,7 @@
 #include <ctype.h>
 #include <string.h>
 #include <errno.h>
-#ifndef _WIN32
+#ifdef HAVE_UNISTD_H
 #  include <unistd.h>
 #endif
 #include "rename.h"
@@ -128,12 +128,12 @@ guint IDL_strcase_hash (gconstpointer v)
 
 gint IDL_strcase_equal (gconstpointer a, gconstpointer b)
 {
-	return g_strcasecmp (a, b) == 0;
+	return g_ascii_strcasecmp (a, b) == 0;
 }
 
 gint IDL_strcase_cmp (gconstpointer a, gconstpointer b)
 {
-	return g_strcasecmp (a, b);
+	return g_ascii_strcasecmp (a, b);
 }
 
 static int my_strcmp (IDL_tree p, IDL_tree q)
@@ -247,7 +247,7 @@ int IDL_parse_filename (const char *filename, const char *cpp_args,
 		return -1;
 	}
 
-#ifndef NO_ACCESS
+#ifdef HAVE_ACCESS
 	if (access (filename, R_OK))
 		return -1;
 #endif
@@ -304,7 +304,7 @@ int IDL_parse_filename (const char *filename, const char *cpp_args,
 	}
 	strcpy (tmpfilename, s);
 	strcat (tmpfilename, ".c");
-#ifndef NO_SYMLINK
+#ifdef HAVE_SYMLINK
 	if (symlink (linkto, tmpfilename) < 0) {
 		g_free (linkto);
 		g_free (tmpfilename);
@@ -328,7 +328,7 @@ int IDL_parse_filename (const char *filename, const char *cpp_args,
 		    cwd, cpp_args ? cpp_args : "", tmpfilename, cpperrs);
 #endif
 
-#ifndef NO_POPEN
+#ifdef HAVE_POPEN
 	input = popen (cmd, "r");
 #else
 	input = fopen (cmd, "r");
@@ -364,7 +364,7 @@ int IDL_parse_filename (const char *filename, const char *cpp_args,
 #ifndef HAVE_CPP_PIPE_STDIN
 	__IDL_tmp_filename = NULL;
 #endif
-#ifndef NO_POPEN
+#ifdef HAVE_POPEN
 	pclose (input);
 #else
 	fclose (input);
@@ -2767,6 +2767,8 @@ static gboolean IDL_emit_IDL_ident_real (IDL_tree_func_data *tfd, IDL_output_dat
 	assert (IDL_NODE_TYPE (tfd->tree) == IDLN_IDENT);
 
 	if (!up_real || data->flags & IDLF_OUTPUT_NO_QUALIFY_IDENTS) {
+		/* TODO: If the IDENT is also a keyword, escape it by
+		   prepending an underscore. */
 		dataf (data, "%s", IDL_IDENT (tfd->tree).str);
 	} else {
 		if ( up_path == 0 ) {
